@@ -670,7 +670,7 @@ class DeviceManager:
                         f'{missing_device_count} times. Restarting bluetooth.',
                     )
                     missing_device_count = 0
-                    await restart_bluetooth()
+                    await restart_bluetooth(self._hci_adapter)
             finally:
                 if self.device.ACTIVE_CONNECTION_MODE not in (
                     ConnectionMode.ACTIVE_POLL_WITH_DISCONNECT,
@@ -706,7 +706,7 @@ class DeviceManager:
                     pass
 
             if failure_count >= FAILURE_LIMIT:
-                await restart_bluetooth()
+                await restart_bluetooth(self._hci_adapter)
                 failure_count = 0
             try:
                 if not device.disconnected_event.is_set():
@@ -725,6 +725,7 @@ class Ble2Mqtt:
 
     def __init__(
             self,
+            ssl,
             host: str,
             port: int = None,
             user: ty.Optional[str] = None,
@@ -743,6 +744,7 @@ class Ble2Mqtt:
         self._mqtt_port = port
         self._mqtt_user = user
         self._mqtt_password = password
+        self._ssl = ssl
         self._base_topic = base_topic
         self._mqtt_config_prefix = mqtt_config_prefix
 
@@ -864,9 +866,13 @@ class Ble2Mqtt:
     def device_detection_callback(self, device: BLEDevice, advertisement_data):
         for reg_device in self.device_registry:
             if reg_device.mac.lower() == device.address.lower():
-                if device.rssi:
+                if hasattr(advertisement_data, 'rssi'):
+                    rssi = advertisement_data.rssi
+                else:
+                    rssi = device.rssi
+                if rssi:
                     # update rssi for all devices if available
-                    reg_device.rssi = device.rssi
+                    reg_device.rssi = rssi
                 if reg_device.is_passive:
                     if device.name:
                         reg_device._model = device.name
@@ -972,6 +978,7 @@ class Ble2Mqtt:
                     port=self._mqtt_port,
                     username=self._mqtt_user,
                     password=self._mqtt_password,
+                    ssl=self._ssl,
                     client_id=f'ble2mqtt_{dev_id}',
                     will_message=aio_mqtt.PublishableMessage(
                         topic_name=self.availability_topic,
