@@ -178,7 +178,6 @@ class BaseDevice(abc.ABC, metaclass=RegisteredType):
 
 
 class Device(BaseDevice, abc.ABC):
-    MQTT_VALUES = None
     SET_POSTFIX: str = 'set'
     SET_POSITION_POSTFIX: str = 'set_position'  # for covers. Consider rework
     SET_MODE_POSTFIX: str = 'set_mode'  # for climate
@@ -534,6 +533,15 @@ class Sensor(Device, abc.ABC):
                 continue
 
             await self.do_active_loop(publish_topic)
+            if (
+                self.ACTIVE_CONNECTION_MODE ==
+                ConnectionMode.ACTIVE_POLL_WITH_DISCONNECT
+            ):
+                if self.client.is_connected:
+                    await self.client.disconnect()
+                # let DeviceManager.manage_device() handle reconnections
+                return
+
             await aio.sleep(self.ACTIVE_SLEEP_INTERVAL)
 
     async def handle_passive(self, publish_topic, send_config, *args, **kwargs):
